@@ -9,7 +9,7 @@ from secrets import token_urlsafe
 from shlex import shlex
 from shutil import move
 from tempfile import mkstemp
-from typing import Iterator, Literal
+from typing import overload, Iterator, Literal
 
 from . import db, email, utils
 
@@ -358,7 +358,13 @@ class Env(PathLike):
 
     def setenv(self) -> None:
         """Add the variables defined in the dotenv file to :os:`environ`."""
-        self.ENV |= self.vars  # type: ignore
+        self.ENV |= self.vars
+
+    @overload
+    def get(self, key: str, default: str) -> str: ...
+
+    @overload
+    def get(self, key: str, default: None = None) -> str | None: ...
 
     def get(self, key: str, default: str | None = None) -> str | None:
         """
@@ -383,6 +389,12 @@ class Env(PathLike):
         """
         return self.ENV.get(key, self.vars.get(key) or default)
 
+    @overload
+    def bool(self, key: str, default: bool) -> bool: ...
+
+    @overload
+    def bool(self, key: str, default: None = None) -> bool | None: ...
+
     def bool(self, key: str, default: bool | None = None) -> bool | None:
         """
         Return an environment variable as a ``bool``, or a default value.
@@ -418,6 +430,12 @@ class Env(PathLike):
             return False
         raise EnvError(f"Invalid boolean value: '{value}'")
 
+    @overload
+    def int(self, key: str, default: int) -> int: ...
+
+    @overload
+    def int(self, key: str, default: None = None) -> int | None: ...
+
     def int(self, key: str, default: int | None = None) -> int | None:
         """
         Return an environment variable as an ``int``, or a default value.
@@ -452,6 +470,12 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid integer value: '{value}'")
 
+    @overload
+    def float(self, key: str, default: float) -> float: ...
+
+    @overload
+    def float(self, key: str, default: None = None) -> float | None: ...
+
     def float(self, key: str, default: float | None = None) -> float | None:
         """
         Return an environment variable as a ``float``, or a default value.
@@ -486,6 +510,13 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid numerical value: '{value}'")
 
+    @overload
+    def list(self, key: str, default: list, separator: str = ...) -> list: ...
+
+    @overload
+    def list(self, key: str, default: None = None,
+              separator: str = ...) -> list | None: ...
+
     def list(self, key: str, default: list | None = None,
              separator: str = ',') -> list | None:
         """
@@ -515,6 +546,12 @@ class Env(PathLike):
             return default
         return value.split(separator)
 
+    @overload
+    def db(self, key: str, default: str) -> db.DBConfig: ...
+
+    @overload
+    def db(self, key: str, default: None = None) -> db.DBConfig | None: ...
+
     def db(self, key: str, default: str | None = None) -> db.DBConfig | None:
         """
         Return a dictionary that can be used for Django's database settings.
@@ -548,6 +585,13 @@ class Env(PathLike):
         except Exception as e:
             raise EnvError(f"Invalid database URL: '{value}'") from e
 
+    @overload
+    def email(self, key: str, default: str) -> email.EmailConfig: ...
+
+    @overload
+    def email(self, key: str, default: None = None
+              ) -> email.EmailConfig | None: ...
+
     def email(self, key: str, default: str | None
               = None) -> email.EmailConfig | None:
         """
@@ -611,7 +655,7 @@ class Env(PathLike):
 
         if value is not None:
             value = value.replace('"', '\\"') \
-                .replace('\n', '\\n').replace('\t', '\\t')
+                    .replace('\n', '\\n').replace('\t', '\\t')
             newline = f'{key}="{value}"\n'
 
         with open(target, 'w') as tf, open(self.envfile, 'r') as sf:
